.. _core_foundation_toplevel:

=================================================
SQL Expression Language Foundational Constructs
=================================================

Base classes and mixins that are used to compose SQL Expression Language
elements.

.. currentmodule:: sqlalchemy.sql.expression

.. autoclass:: CacheKey
   :members:

.. autoclass:: ClauseElement
   :members:
   :inherited-members:


.. autoclass:: sqlalchemy.sql.base.DialectKWArgs
   :members:


.. autoclass:: sqlalchemy.sql.traversals.HasCacheKey
    :members:

.. autoclass:: LambdaElement
   :members:

.. autoclass:: StatementLambdaElement
   :members:

